==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/imt.php <==
<?php
//bobg 27jun09 24dec 9may12
// PJC 16 SEPT FIX corrupt characters
$page_id = "035";
include "assist/.access.php";
include "assist/tzone.php"; // include timezone
$script=basename($_SERVER['SCRIPT_NAME']);
?>
<html>
<head>
<title>Intra Module Trunk - View Status</title>
<link rel="stylesheet" type="text/css" href="css/Styles.css" media="screen" />
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body  bgcolor="#CCFFFF">
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo $script?>'" src="assist/images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('assist/help/help_imt.php','help','600','500','yes');return false" src="assist/images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist/assist.php'" src="assist/images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="assist/images/home16.gif" alt="home" title="home" border="0">
</div>
<br/>
<div id="contain">
<h2><img src='assist/images/ok.png' style="vertical-align:middle;">&nbsp;Intra Module Trunk - View Status</h2>
<?php
$ds = @ldap_connect("127.0.0.1",4000) or exit("<p>EXIT: LDAP connect failure</p>");
ldap_bind($ds,"INTERNAL","001122334455") or exit("<p>EXIT: LDAP bind failure</p>");
// build array of nodes
$sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
$info=ldap_get_entries($ds,$sr);
//print "Module count = ".$info['count']."<br/>";
for($n=0; $n<$info['count'];$n++) {
	$modules['cn'][$n] = $info[$n]['cn'][0];
	$modules['guid'][$n] = $info[$n]['guid'][0];
    $modules['version'][$n] = $info[$n]['productversion'][0];
   if ($info[$n]['moduletype'][0]==1) $modules['type'][$n]="4100";
   if ($info[$n]['moduletype'][0]==1 and substr($info[$n]['serialnumber'][0],0,8)!="00-07-d9") $modules['type'][$n]="XS";
   if ($info[$n]['moduletype'][0]==10) $modules['type'][$n]="4140";
   if ($info[$n]['moduletype'][0]==11) $modules['type'][$n]="5100";
   if ($info[$n]['moduletype'][0]==12) $modules['type'][$n]="5108";
   if ($info[$n]['moduletype'][0]==17) $modules['type'][$n]="S8000 Linux";
   if ($info[$n]['moduletype'][0]==18) $modules['type'][$n]="S8000 Apple";
   if ($info[$n]['moduletype'][0]==19) $modules['type'][$n]="NSG";
   $modules['ipaddress'][$n] = $info[$n]['ipaddress'][0];
   $modules['ipaddress0'][$n] = $info[$n]['ipaddress'][0];
   $dn = "cn=1,".$info[$n]['dn'];
   $sr=ldap_read($ds,$dn,"objectclass=*");
   $infox=ldap_get_entries($ds,$sr);
   if (($infox[0]['administrationmode'][0])=="1") $modules['cn'][$n] = "<i>".$info[$n]['cn'][0]."</i>";
//   if (($infox[0]['publicipaddress'][0])=="") $modules['publicipaddress'][$n] = "&nbsp;";
//   else
    $modules['publicipaddress'][$n] = $infox[0]['publicipaddress'][0];
    if ($infox[0]['publicipaddress'][0]!="") $modules['ipaddress0'][$n] = $infox[0]['publicipaddress'][0];
}
print "<table border=1>";
print "<tr><td align='right'><b>Call Server</b><br/>Public IP<br/>Real IP</td>";
foreach($modules['cn'] as $k => $v) print "<td><b>$v<br/></b>to:</td>";
print "</tr>";
/*
print "<tr><td align='right'>Real IP Address =</td>";
foreach($modules['ipaddress'] as $k => $v) print "<td>$v</td>";
print "</tr>";
print "<tr><td align='right'>Public IP Address =</td>";
foreach($modules['publicipaddress'] as $k => $v) print "<td>$v</td>";
print "</tr>";
*/
function validip($s){
  $s2=str_replace( array('1','2','3','4','5','6','7','8','9','0','.'),'',$s);
  if (strlen($s2)) return ("'$s' ???");
  else return ($s);
}
foreach($modules['cn'] as $k => $v){
  $pipa=validip($modules['publicipaddress'][$k]);
  $ripa=validip($modules['ipaddress'][$k]);
   print "<tr><td align='right'><b>$v</b><br/>$pipa<br/>$ripa</td>";
   $m=$modules['guid'][$k];
   foreach($modules['guid'] as $k2 => $v2) {
      $dn="guid=$v2";
      $search="(&(objectclass=Member)(member=$m))";
      $sr=ldap_search($ds,$dn,$search);
      $info_m=ldap_get_entries($ds,$sr);
      $ip="";
      if ($info_m['count']) {
         for ($n=0;$n<$info_m['count'];$n++) {
            $dn=substr($info_m[$n]['dn'],strpos($info_m[$n]['dn'],',')+1);
            $sr=ldap_read($ds,$dn,"objectclass=*");
            $info_imt=ldap_get_entries($ds,$sr);
            $ctname=$ct=$info_imt[0]['compressiontype'][0];
            if ($ct==0) $ctname="None ";
            elseif ($ct==11) $ctname="G729a ";
            elseif ($ct==12) $ctname="Relay ";
            $cap = $info_imt[0]['capacity'][0];
            $res = $info_imt[0]['reserveincomingcapacity'][0];
            if ($res==0) $res=""; else $res=" ($res)";
            $oipa=$info_imt[0]['ipaddress'][0];
            if ($pipa=="") $ipa=$ripa;
            elseif ($oipa=="") $ipa=$pipa;
            else {
                $ipa=$oipa;
                if ($ipa!=$ripa) $ipa="$ipa ???";
            }
            $ip .= "$v<br/>via: <b>".$info_imt[0]['cn'][0]."</b><br/>$ctname $cap$res<br/>$ipa<br/>";
         }
      }
      elseif($m==$v2) ;
      else {
         $sr=ldap_search($ds,$dn,"objectclass=IntraModuleTrunk");
         $info_imt=ldap_get_entries($ds,$sr);
//$ip .= " ".$info_imt['count']." ";
         for ($n=0;$n<$info_imt['count'];$n++) {
            $dn2=$info_imt[$n]['dn'];
            $sr2=ldap_list($ds,$dn2,"objectclass=Member");
            $info_m=ldap_get_entries($ds,$sr2);
            if ($info_m['count']) continue;
//$ip .= " $n ";
            $ctname=$ct=$info_imt[$n]['compressiontype'][0];
            if ($ct==0) $ctname="None ";
            elseif ($ct==11) $ctname="G729a ";
            elseif ($ct==12) $ctname="Relay ";
            $cap = $info_imt[$n]['capacity'][0];
            $res = $info_imt[$n]['reserveincomingcapacity'][0];
            if ($res==0) $res=""; else $res=" ($res)";
            if ($pipa=="") $ipa=$ripa;
            elseif ($info_imt[$n]['ipaddress'][0]=="") $ipa=$pipa;
            else {
                $ipa=$info_imt[$n]['ipaddress'][0];
                if ($ipa!=$ripa) $ipa="$ipa?";
            }
            $ip .= "$v<br/>via: <b>".$info_imt[$n]['cn'][0]."</b><br/>$ctname $cap$res<br/>$ipa<br/>";
            break;
         }
      }
      if ($ip==" 0 " or $ip=="") $ip="&nbsp;";
      print "<td>$ip</td>";
   }
   print "</tr>\n";
}
print "</table><br/>".date("Y-m-d H:i:s");
?>
<p>The table should be read down the columns. The items in the centre of the table are made up of: destination call server, the intra module trunk name, compression type + capacity + (reserved) if set, and routing ip address to that call server.</p>
<p>When configuring a system with Public IP Address or compression it's sometimes a bit difficult to see the big picture, especially if you have Intra Module Trunk entries - hence this page.<br/>
Public IP Addresses are users for applications like Total Control.</p>
<p>If a Call Server wishes to contact another Call Server, it always uses that Call Servers Public IP Address in preference to its Real IP Address, unless there is an entry in the originators Intra Module Trunk configuration to say use 'this' address instead. If there is no Public IP Address for the destination, then it will always use the Real IP Address. The trunk entry makes it possible for 2 Call Servers on the same site to communicate directly without going thru their public connections.</p>
<p>Typically we use an Intra Module Trunk called 'Others' with no Modules added to avoid too much typing and simplify the configuration. We only add trunks with modules when we have to, and use geographic names like Chorleywood5100.</p>
</div>
</body>
</html>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/imt.php <==
<?php
//bobg 27jun09 24dec 9may12
// PJC 07 July 2020 Updated wording to SoftPBX
// PJC 16 SEPT FIX corrupt characters
$page_id = "035";
include "assist/.access.php";
include "assist/tzone.php"; // include timezone
$script=basename($_SERVER['SCRIPT_NAME']);
?>
<html>
<head>
<title>Intra Module Trunk - View Status</title>
<link rel="stylesheet" type="text/css" href="css/Styles.css" media="screen" />
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body  bgcolor="#CCFFFF">
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo $script?>'" src="assist/images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('assist/help/help_imt.php','help','600','500','yes');return false" src="assist/images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist/assist.php'" src="assist/images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="assist/images/home16.gif" alt="home" title="home" border="0">
</div>
<br/>
<div id="contain">
<h2><img src='assist/images/ok.png' style="vertical-align:middle;">&nbsp;Intra Module Trunk - View Status</h2>
<?php
$ds = @ldap_connect("127.0.0.1",4000) or exit("<p>EXIT: LDAP connect failure</p>");
ldap_bind($ds,"INTERNAL","001122334455") or exit("<p>EXIT: LDAP bind failure</p>");
// build array of nodes
$sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
$info=ldap_get_entries($ds,$sr);
//print "Module count = ".$info['count']."<br/>";
for($n=0; $n<$info['count'];$n++) {
	$modules['cn'][$n] = $info[$n]['cn'][0];
	$modules['guid'][$n] = $info[$n]['guid'][0];
    $modules['version'][$n] = $info[$n]['productversion'][0];
   if ($info[$n]['moduletype'][0]==1) $modules['type'][$n]="4100";
   if ($info[$n]['moduletype'][0]==1 and substr($info[$n]['serialnumber'][0],0,8)!="00-07-d9") $modules['type'][$n]="XS";
   if ($info[$n]['moduletype'][0]==10) $modules['type'][$n]="4140";
   if ($info[$n]['moduletype'][0]==11) $modules['type'][$n]="5100";
   if ($info[$n]['moduletype'][0]==12) $modules['type'][$n]="5108";
   if ($info[$n]['moduletype'][0]==17) $modules['type'][$n]="SoftPBX Linux";
   if ($info[$n]['moduletype'][0]==18) $modules['type'][$n]="SoftPBX Apple";
   if ($info[$n]['moduletype'][0]==19) $modules['type'][$n]="NSG";
   $modules['ipaddress'][$n] = $info[$n]['ipaddress'][0];
   $modules['ipaddress0'][$n] = $info[$n]['ipaddress'][0];
   $dn = "cn=1,".$info[$n]['dn'];
   $sr=ldap_read($ds,$dn,"objectclass=*");
   $infox=ldap_get_entries($ds,$sr);
   if (($infox[0]['administrationmode'][0])=="1") $modules['cn'][$n] = "<i>".$info[$n]['cn'][0]."</i>";
//   if (($infox[0]['publicipaddress'][0])=="") $modules['publicipaddress'][$n] = "&nbsp;";
//   else
    $modules['publicipaddress'][$n] = $infox[0]['publicipaddress'][0];
    if ($infox[0]['publicipaddress'][0]!="") $modules['ipaddress0'][$n] = $infox[0]['publicipaddress'][0];
}
print "<table border=1>";
print "<tr><td align='right'><b>Call Server</b><br/>Public IP<br/>Real IP</td>";
foreach($modules['cn'] as $k => $v) print "<td><b>$v<br/></b>to:</td>";
print "</tr>";
/*
print "<tr><td align='right'>Real IP Address =</td>";
foreach($modules['ipaddress'] as $k => $v) print "<td>$v</td>";
print "</tr>";
print "<tr><td align='right'>Public IP Address =</td>";
foreach($modules['publicipaddress'] as $k => $v) print "<td>$v</td>";
print "</tr>";
*/
function validip($s){
  $s2=str_replace( array('1','2','3','4','5','6','7','8','9','0','.'),'',$s);
  if (strlen($s2)) return ("'$s' ???");
  else return ($s);
}
foreach($modules['cn'] as $k => $v){
  $pipa=validip($modules['publicipaddress'][$k]);
  $ripa=validip($modules['ipaddress'][$k]);
   print "<tr><td align='right'><b>$v</b><br/>$pipa<br/>$ripa</td>";
   $m=$modules['guid'][$k];
   foreach($modules['guid'] as $k2 => $v2) {
      $dn="guid=$v2";
      $search="(&(objectclass=Member)(member=$m))";
      $sr=ldap_search($ds,$dn,$search);
      $info_m=ldap_get_entries($ds,$sr);
      $ip="";
      if ($info_m['count']) {
         for ($n=0;$n<$info_m['count'];$n++) {
            $dn=substr($info_m[$n]['dn'],strpos($info_m[$n]['dn'],',')+1);
            $sr=ldap_read($ds,$dn,"objectclass=*");
            $info_imt=ldap_get_entries($ds,$sr);
            $ctname=$ct=$info_imt[0]['compressiontype'][0];
            if ($ct==0) $ctname="None ";
            elseif ($ct==11) $ctname="G729a ";
            elseif ($ct==12) $ctname="Relay ";
            $cap = $info_imt[0]['capacity'][0];
            $res = $info_imt[0]['reserveincomingcapacity'][0];
            if ($res==0) $res=""; else $res=" ($res)";
            $oipa=$info_imt[0]['ipaddress'][0];
            if ($pipa=="") $ipa=$ripa;
            elseif ($oipa=="") $ipa=$pipa;
            else {
                $ipa=$oipa;
                if ($ipa!=$ripa) $ipa="$ipa ???";
            }
            $ip .= "$v<br/>via: <b>".$info_imt[0]['cn'][0]."</b><br/>$ctname $cap$res<br/>$ipa<br/>";
         }
      }
      elseif($m==$v2) ;
      else {
         $sr=ldap_search($ds,$dn,"objectclass=IntraModuleTrunk");
         $info_imt=ldap_get_entries($ds,$sr);
//$ip .= " ".$info_imt['count']." ";
         for ($n=0;$n<$info_imt['count'];$n++) {
            $dn2=$info_imt[$n]['dn'];
            $sr2=ldap_list($ds,$dn2,"objectclass=Member");
            $info_m=ldap_get_entries($ds,$sr2);
            if ($info_m['count']) continue;
//$ip .= " $n ";
            $ctname=$ct=$info_imt[$n]['compressiontype'][0];
            if ($ct==0) $ctname="None ";
            elseif ($ct==11) $ctname="G729a ";
            elseif ($ct==12) $ctname="Relay ";
            $cap = $info_imt[$n]['capacity'][0];
            $res = $info_imt[$n]['reserveincomingcapacity'][0];
            if ($res==0) $res=""; else $res=" ($res)";
            if ($pipa=="") $ipa=$ripa;
            elseif ($info_imt[$n]['ipaddress'][0]=="") $ipa=$pipa;
            else {
                $ipa=$info_imt[$n]['ipaddress'][0];
                if ($ipa!=$ripa) $ipa="$ipa?";
            }
            $ip .= "$v<br/>via: <b>".$info_imt[$n]['cn'][0]."</b><br/>$ctname $cap$res<br/>$ipa<br/>";
            break;
         }
      }
      if ($ip==" 0 " or $ip=="") $ip="&nbsp;";
      print "<td>$ip</td>";
   }
   print "</tr>\n";
}
print "</table><br/>".date("Y-m-d H:i:s");
?>
<p>The table should be read down the columns. The items in the centre of the table are made up of: destination call server, the intra module trunk name, compression type + capacity + (reserved) if set, and routing ip address to that call server.</p>
<p>When configuring a system with Public IP Address or compression it's sometimes a bit difficult to see the big picture, especially if you have Intra Module Trunk entries - hence this page.<br/>
Public IP Addresses are users for applications like Total Control.</p>
<p>If a Call Server wishes to contact another Call Server, it always uses that Call Servers Public IP Address in preference to its Real IP Address, unless there is an entry in the originators Intra Module Trunk configuration to say use 'this' address instead. If there is no Public IP Address for the destination, then it will always use the Real IP Address. The trunk entry makes it possible for 2 Call Servers on the same site to communicate directly without going thru their public connections.</p>
<p>Typically we use an Intra Module Trunk called 'Others' with no Modules added to avoid too much typing and simplify the configuration. We only add trunks with modules when we have to, and use geographic names like Chorleywood5100.</p>
</div>
</body>
</html>
